@@ -306,35 +306,35 @@ sub check_menu_sens {
 	
 
 	if ($item->[0]) { #service is active
-	    $bum_app::gladexml->get_widget('activate_apply_now1')->set_sensitive(FALSE);
-		$bum_app::gladexml->get_widget('deactivate_apply_now1')->set_sensitive(TRUE);
+	    $bum_app::uixml->get_object('activate_apply_now1')->set_sensitive(FALSE);
+		$bum_app::uixml->get_object('deactivate_apply_now1')->set_sensitive(TRUE);
 		if ($page==$application->STA_PAGE) {
-			$bum_app::gladexml->get_widget('priority1')->set_sensitive(TRUE);
+			$bum_app::uixml->get_object('priority1')->set_sensitive(TRUE);
 			}  
 		}
 	else { #service is deactived
-		$bum_app::gladexml->get_widget('activate_apply_now1')->set_sensitive(TRUE); #activate
-		$bum_app::gladexml->get_widget('deactivate_apply_now1')->set_sensitive(FALSE);
-		$bum_app::gladexml->get_widget('priority1')->set_sensitive(FALSE);
+		$bum_app::uixml->get_object('activate_apply_now1')->set_sensitive(TRUE); #activate
+		$bum_app::uixml->get_object('deactivate_apply_now1')->set_sensitive(FALSE);
+		$bum_app::uixml->get_object('priority1')->set_sensitive(FALSE);
 	}
 
 	my $running = bumlib::check_if_running($item->[$servicecol]);
 		
 	if (!defined($running)) {
-		$bum_app::gladexml->get_widget('start_service_now1')->set_sensitive(TRUE);  #start service
-		$bum_app::gladexml->get_widget('stop_service_now1')->set_sensitive(TRUE);  #stop service
+		$bum_app::uixml->get_object('start_service_now1')->set_sensitive(TRUE);  #start service
+		$bum_app::uixml->get_object('stop_service_now1')->set_sensitive(TRUE);  #stop service
 	}
 	elsif ($running==TRUE) { 
-		$bum_app::gladexml->get_widget('start_service_now1')->set_sensitive(FALSE);  #start service
-		$bum_app::gladexml->get_widget('stop_service_now1')->set_sensitive(TRUE);  #stop service
+		$bum_app::uixml->get_object('start_service_now1')->set_sensitive(FALSE);  #start service
+		$bum_app::uixml->get_object('stop_service_now1')->set_sensitive(TRUE);  #stop service
 	}
 	elsif($running==FALSE){
-		$bum_app::gladexml->get_widget('start_service_now1')->set_sensitive(TRUE);  #start service
-		$bum_app::gladexml->get_widget('stop_service_now1')->set_sensitive(FALSE);  #stop service
+		$bum_app::uixml->get_object('start_service_now1')->set_sensitive(TRUE);  #start service
+		$bum_app::uixml->get_object('stop_service_now1')->set_sensitive(FALSE);  #stop service
 	}
 	elsif($running==-1){
-		$bum_app::gladexml->get_widget('start_service_now1')->set_sensitive(FALSE);  #start service
-		$bum_app::gladexml->get_widget('stop_service_now1')->set_sensitive(FALSE);  #stop service
+		$bum_app::uixml->get_object('start_service_now1')->set_sensitive(FALSE);  #start service
+		$bum_app::uixml->get_object('stop_service_now1')->set_sensitive(FALSE);  #stop service
 	}
 
 	set_info_text() if ($page != $application->SUM_PAGE);
@@ -343,8 +343,8 @@ sub check_menu_sens {
 ##############################
 sub start_progress
 {
-	my $prog_win = $bum_app::gladexml->get_widget('prog_win');
-	my $prog_bar = $bum_app::gladexml->get_widget('progressbar1');
+	my $prog_win = $bum_app::uixml->get_object('prog_win');
+	my $prog_bar = $bum_app::uixml->get_object('progressbar1');
 	$prog_bar->pulse();
 	$prog_win->set_icon(Gtk2::Gdk::Pixbuf->new_from_file($application->icon_path));
 	$prog_win->set_transient_for($application->window);
@@ -368,7 +368,7 @@ sub destroy_progress
 	my $pbar = shift;
 	Glib::Source->remove($pbar->{timer});
 	
-	$bum_app::gladexml->get_widget('prog_win')->destroy;
+	$bum_app::uixml->get_object('prog_win')->destroy;
 		
 	}
 
@@ -513,20 +513,20 @@ sub change_page
 		set_info_text() if ($page != 0);
 		
 	if  ($page==$application->SUM_PAGE){		
-		$bum_app::gladexml->get_widget('applica1')->set_sensitive(TRUE);
-		$bum_app::gladexml->get_widget('apply_btn')->set_sensitive(TRUE);
-		$bum_app::gladexml->get_widget('services1')->set_sensitive(TRUE);
-		$bum_app::gladexml->get_widget('priority1')->set_sensitive(FALSE);      
+		$bum_app::uixml->get_object('applica1')->set_sensitive(TRUE);
+		$bum_app::uixml->get_object('apply_btn')->set_sensitive(TRUE);
+		$bum_app::uixml->get_object('services1')->set_sensitive(TRUE);
+		$bum_app::uixml->get_object('priority1')->set_sensitive(FALSE);      
 	}
 	elsif ($page ==$application->RCS_PAGE) {
-		$bum_app::gladexml->get_widget('services1')->set_sensitive(FALSE);
-		$bum_app::gladexml->get_widget('applica1')->set_sensitive(FALSE);
-		$bum_app::gladexml->get_widget('apply_btn')->set_sensitive(FALSE);
+		$bum_app::uixml->get_object('services1')->set_sensitive(FALSE);
+		$bum_app::uixml->get_object('applica1')->set_sensitive(FALSE);
+		$bum_app::uixml->get_object('apply_btn')->set_sensitive(FALSE);
 	}
  	elsif ($page == $application->STA_PAGE) {
-		$bum_app::gladexml->get_widget('applica1')->set_sensitive(TRUE);
-		$bum_app::gladexml->get_widget('apply_btn')->set_sensitive(TRUE);
-		$bum_app::gladexml->get_widget('services1')->set_sensitive(TRUE);
+		$bum_app::uixml->get_object('applica1')->set_sensitive(TRUE);
+		$bum_app::uixml->get_object('apply_btn')->set_sensitive(TRUE);
+		$bum_app::uixml->get_object('services1')->set_sensitive(TRUE);
 		check_menu_sens();
 	}
 }
@@ -711,10 +711,10 @@ sub change_priority {
 	my ($priority_dlg, $service_label, $serv_name, $start_pri, $stop_pri, $start_spin,$stop_spin);
 	my $item= get_current_row();
 	
-	$priority_dlg = $bum_app::gladexml->get_widget('priority_dlg');
-	$service_label = $bum_app::gladexml->get_widget('priority_label');
-	$start_spin = $bum_app::gladexml->get_widget('start_spin');	
-	$stop_spin = $bum_app::gladexml->get_widget('stop_spin');
+	$priority_dlg = $bum_app::uixml->get_object('priority_dlg');
+	$service_label = $bum_app::uixml->get_object('priority_label');
+	$start_spin = $bum_app::uixml->get_object('start_spin');	
+	$stop_spin = $bum_app::uixml->get_object('stop_spin');
 	$priority_dlg->set_transient_for($application->window);
 	
 	$serv_name = $item->[STA_SERVICE];
